unit testFileDeleter;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, FileCtrl, FileDeleter, ComCtrls, ExtCtrls, Menus;

type
  TfrmFileDeleterTest = class(TForm)
    OpenDialog1: TOpenDialog;
    SaveDialog1: TSaveDialog;
    MainMenu1: TMainMenu;
    miFile: TMenuItem;
    miOpen: TMenuItem;
    miSave: TMenuItem;
    N1: TMenuItem;
    miExit: TMenuItem;
    PageControl: TPageControl;
    tsGeneral: TTabSheet;
    Panel1: TPanel;
    gbDirs: TGroupBox;
    dirListSelect: TDirectoryListBox;
    Panel2: TPanel;
    Label1: TLabel;
    Panel3: TPanel;
    lbSelDir: TLabel;
    Panel4: TPanel;
    btnAddDir: TButton;
    Panel5: TPanel;
    btnClearDirs: TButton;
    gbMasks: TGroupBox;
    Panel6: TPanel;
    edMask: TEdit;
    Panel7: TPanel;
    Label2: TLabel;
    Panel8: TPanel;
    btnAddMask: TButton;
    meMasks: TMemo;
    Panel9: TPanel;
    btnClearMasks: TButton;
    gbDelete: TGroupBox;
    Panel10: TPanel;
    cbRecDirs: TCheckBox;
    Panel11: TPanel;
    cbPreview: TCheckBox;
    Panel12: TPanel;
    btnDelete: TButton;
    meDeletedFiles: TMemo;
    Panel13: TPanel;
    btnClearAll: TButton;
    tsAdvanced: TTabSheet;
    pnlEnableAdvanced: TPanel;
    pnlAdvanced: TPanel;
    cbAdvancedEnabled: TCheckBox;
    gbDateRange: TGroupBox;
    Panel14: TPanel;
    pnlFromDate: TPanel;
    cbFromDate: TCheckBox;
    fromDate: TDateTimePicker;
    fromTime: TDateTimePicker;
    Panel16: TPanel;
    pnlToDate: TPanel;
    toDate: TDateTimePicker;
    toTime: TDateTimePicker;
    cbToDate: TCheckBox;
    meDirs: TMemo;
    procedure FormCreate(Sender: TObject);
    procedure btnAddDirClick(Sender: TObject);
    procedure btnClearDirsClick(Sender: TObject);
    procedure dirListSelectChange(Sender: TObject);
    procedure btnAddMaskClick(Sender: TObject);
    procedure btnClearMasksClick(Sender: TObject);
    procedure cbRecDirsClick(Sender: TObject);
    procedure cbPreviewClick(Sender: TObject);
    procedure btnDeleteClick(Sender: TObject);
    procedure btnClearAllClick(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure miExitClick(Sender: TObject);
    procedure miOpenClick(Sender: TObject);
    procedure miSaveClick(Sender: TObject);
    procedure cbAdvancedEnabledClick(Sender: TObject);
    procedure cbFromDateClick(Sender: TObject);
    procedure cbToDateClick(Sender: TObject);
  private
    { Private declarations }
    fd : TFileDeleter;

    procedure setAdvanced;
    procedure getAdvanced;
  public
    { Public declarations }
  end;

var
  frmFileDeleterTest: TfrmFileDeleterTest;

implementation

{$R *.DFM}

procedure TfrmFileDeleterTest.FormCreate(Sender: TObject);
begin
//  Application.Title := 'File Deleter - Test';
//  Application.Title := 'File Deleter - V1.0.2';
  Application.Title := 'File Deleter - V1.0.3';
  frmFileDeleterTest.Caption := Application.Title;

  fd := TFileDeleter.create();
  try
    dirListSelect.Directory := 'C:\Documents and Settings\Fabio\Desktop';
  except
  end;

  dirListSelect.Directory := ExtractFileDir(Application.ExeName);
  SaveDialog1.InitialDir := ExtractFileDir(Application.ExeName);


  PageControl.ActivePage := tsGeneral;

//date and time - default
  fromDate.Date := Date();
  fromTime.Time := Time();
  toDate.Date := Date();
  toTime.Time := Time();

  cbAdvancedEnabled.Checked := False;
  cbAdvancedEnabledClick(nil);
  cbFromDate.Checked := False;
  cbFromDateClick(nil);
  cbToDate.Checked := False;
  cbToDateClick(nil);
end;

procedure TfrmFileDeleterTest.btnAddDirClick(Sender: TObject);
begin
  fd.addDirectory(lbSelDir.Caption);
  fd.getDirectories(meDirs.Lines);
end;

procedure TfrmFileDeleterTest.btnClearDirsClick(Sender: TObject);
begin
  fd.clearAllDirectories;
  fd.getDirectories(meDirs.Lines);
end;

procedure TfrmFileDeleterTest.dirListSelectChange(Sender: TObject);
begin
  lbSelDir.Caption := dirListSelect.Directory;
end;

procedure TfrmFileDeleterTest.btnAddMaskClick(Sender: TObject);
begin
  if Trim(edMask.Text) > '' then
  begin
    fd.addFileNameMask(edMask.Text);
    fd.getFileNameMasks(meMasks.Lines);
  end;  
end;

procedure TfrmFileDeleterTest.btnClearMasksClick(Sender: TObject);
begin
  fd.clearAllFileNameMasks;
  fd.getFileNameMasks(meMasks.Lines);
  edMask.Text := '';
end;

procedure TfrmFileDeleterTest.cbRecDirsClick(Sender: TObject);
begin
  fd.setRecursiveDirs(cbRecDirs.Checked);
end;

procedure TfrmFileDeleterTest.cbPreviewClick(Sender: TObject);
begin
  fd.setPreviewMode(cbPreview.Checked);
end;

procedure TfrmFileDeleterTest.btnDeleteClick(Sender: TObject);
begin
  setAdvanced;
  fd.delFiles(meDeletedFiles.Lines);
end;

procedure TfrmFileDeleterTest.btnClearAllClick(Sender: TObject);
begin
  fd.clearAll;

  cbRecDirs.Checked := False;
  cbPreview.Checked := False;
  meDeletedFiles.Clear;
  fd.getDirectories(meDirs.Lines);
  fd.getFileNameMasks(meMasks.Lines);
  edMask.Text := '';
  
end;

procedure TfrmFileDeleterTest.FormClose(Sender: TObject;
  var Action: TCloseAction);
begin
  miExitClick(nil);
end;

procedure TfrmFileDeleterTest.miExitClick(Sender: TObject);
begin
  if MessageDlg('Do You  Want To Close ' + Application.Title + '?',
    mtConfirmation, [mbYes,mbNo], 0) = mrYes then
    Application.Terminate
  else
    Abort
end;

procedure TfrmFileDeleterTest.miOpenClick(Sender: TObject);
begin
  if OpenDialog1.Execute then
  begin
    fd.setParamsFileName(OpenDialog1.FileName);
    if fd.loadParamsFromFile = 0 then //no error
    begin
      fd.getDirectories(meDirs.Lines);
      fd.getFileNameMasks(meMasks.Lines);
      edMask.Text := '';
      cbPreview.Checked := fd.getPreviewMode;
      cbRecDirs.Checked := fd.getRecursiveDirs;
      getAdvanced;
    end;
  end;
end;

procedure TfrmFileDeleterTest.miSaveClick(Sender: TObject);
var
  i : integer;
  doSave : boolean;
begin
  doSave := False;
  if SaveDialog1.Execute then
  begin
    if FileExists(SaveDialog1.FileName) then
    begin
      if (MessageDlg(SaveDialog1.FileName + ' already exists.'
        +#13+#10+'Do you want to replace it?', mtWarning, [mbYes,mbNo], 0) = mrYes) then
      doSave := True;
    end
    else
      doSave := True;
  end;

  if doSave then
  begin
    setAdvanced;
    fd.setParamsFileName(SaveDialog1.FileName);
    i := fd.saveParamsToFile;
    if i <> 0 then // error
      MessageDlg('An error occurred while trying to save this configuration to the file.'
        +#13+#10+'Error Code: ' + IntToStr(i), mtError, [mbOK], 0);
  end;
end;

procedure TfrmFileDeleterTest.cbAdvancedEnabledClick(Sender: TObject);
begin
  if Assigned(fd) then
    fd.setUseAdvanced(cbAdvancedEnabled.Checked);
  pnlAdvanced.Enabled := cbAdvancedEnabled.Checked;
end;

procedure TfrmFileDeleterTest.cbFromDateClick(Sender: TObject);
begin
  if Assigned(fd) then
  begin
    fd.setUseFromDate(cbFromDate.Checked);
    pnlFromDate.Enabled := cbFromDate.Checked;
  end;
end;

procedure TfrmFileDeleterTest.cbToDateClick(Sender: TObject);
begin
  if Assigned(fd) then
  begin
    fd.setUseToDate(cbToDate.Checked);
    pnlToDate.Enabled := cbToDate.Checked;
  end;  
end;

procedure TfrmFileDeleterTest.setAdvanced;
begin
  if cbAdvancedEnabled.Checked then
  begin
    if cbFromDate.Checked then
    begin
      fd.setFromDate(fromDate.Date);
      fd.setFromTime(fromTime.Time);
    end;
    if cbToDate.Checked then
    begin
      fd.setToDate(toDate.Date);
      fd.setToTime(toTime.Time);
    end;
  end;

end;

procedure TfrmFileDeleterTest.getAdvanced;
begin
  if Assigned(fd) then
  begin
    pnlAdvanced.Enabled := fd.getUseAdvanced;
    cbAdvancedEnabled.Checked := fd.getUseAdvanced;

    pnlFromDate.Enabled := fd.getUseFromDate;
    cbFromDate.Checked := fd.getUseFromDate;
    pnlToDate.Enabled := fd.getUseToDate;
    cbToDate.Checked := fd.getUseToDate;
    if pnlFromDate.Enabled then
    begin
      fromDate.Date := fd.getFromDate;
      fromTime.Time := fd.getFromTime;
    end;
    if pnlToDate.Enabled then
    begin
      toDate.Date := fd.getToDate;
      toTime.Time := fd.getToTime;
    end;
  end;
end;

end.
